//////////////////////////////////////////////////
// GMSH geometry for circular slab/sheet
//
// usage:
//  gmsh -2 [ options] Disc.geo
//
// options: 
//  -setnumber R 0.080      // radius
//  -setnumber T 0.150      // thickness in z-direction (0 for sheet)
//  -clscale XX             // overall scaling factor for mesh resolution
//
// Homer Reid 9/2016
//////////////////////////////////////////////////

////////////////////////////////////////////////////
// user-specifiable parameters 
////////////////////////////////////////////////////

// radius
DefineConstant[ R = 0.100 ];

// thickness
DefineConstant[ T = 0.000 ];

// meshing scale factor
DefineConstant[ MeshScale = 1 ];
LS = 0.5*R*MeshScale;

DefineConstant[ N = 3 ];

////////////////////////////////////////////////////
// end of user-specifiable parameters 
////////////////////////////////////////////////////
Point(1) = { R,  0, -T/2, LS};
Extrude { {0,0,1}, {0, 0, 0}, 2*Pi/3 } { Point{1}; Layers{N}; }
Extrude { {0,0,1}, {0, 0, 0}, 2*Pi/3 } { Point{2}; Layers{N}; }
Extrude { {0,0,1}, {0, 0, 0}, 2*Pi/3 } { Point{4}; Layers{N}; }

Line Loop(1)={1,2,3};
Ruled Surface(1) = {1};

// for the finite-thickness case, extrude in the z direction
If (T!=0)

  NLayers = Ceil[T/LS];
  If (NLayers<2)
   NLayers=2;
  EndIf
  Extrude {0,0,T} { Surface{1}; Layers{NLayers}; }

EndIf
